==> ecuacion-splib-web-1.64.0-sources.jar: jp/ecuacion/splib/web/tool/bean/RequestResultBean.java <==
package jp.ecuacion.splib.web.tool.bean;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.HashSet;
import java.util.List;
import java.util.Set;
import java.util.stream.Collectors;

public class RequestResultBean {
  public static final String key = "result";

  private WarnMessageBean warnMessage;

  /**
   * spring mvc標準のbean validationのエラー処理を使用しない場合に使用する。 並び順を保持するためにListを使用。
   */
  private List<ErrorMessageBean> errorMessageList = new ArrayList<>();

  private List<String> getErrorMessageList(String itemName) {
    List<String> returnList = new ArrayList<>();

    for (ErrorMessageBean bean : errorMessageList) {
      if (bean.getItemNameSet().contains(itemName)) {
        returnList.add(bean.message);
      }
    }

    return returnList;
  }

  public WarnMessageBean getWarnMessage() {
    return warnMessage;
  }

  public void setWarnMessage(WarnMessageBean warnMessage) {
    this.warnMessage = warnMessage;
  }

  public void setWarnMessage(String messageId, String message) {
    this.warnMessage = new WarnMessageBean(messageId, message);
  }

  public void setErrorMessage(String message) {
    errorMessageList.add(new ErrorMessageBean(message));
  }

  public void setErrorMessage(String message, String... itemName) {
    errorMessageList.add(new ErrorMessageBean(message, itemName));
  }

  /**
   * 全てのエラーを取得
   */
  public List<String> getErrorMessages() {
    List<String> rtnList = new ArrayList<>();

    for (ErrorMessageBean bean : errorMessageList) {
      rtnList.add(bean.getMessage());
    }

    return rtnList;
  }

  /**
   * 指定されたitemに対する全てのエラーを取得
   */
  public List<String> getErrorMessages(String itemName) {
    return getErrorMessageList(itemName);
  }

  /**
   * item指定のある全てのエラーを取得
   */
  public List<String> getErrorMessagesLinkedToItems() {
    return errorMessageList.stream()
        .filter(e -> e.getItemNameSet().size() > 0)
        .map(e -> e.getMessage())
        .collect(Collectors.toList());
  }

  /**
   * item指定のない全てのエラーを取得
   */
  public List<String> getErrorMessagesNotLinkedToItems() {
    return errorMessageList.stream()
        .filter(e -> e.getItemNameSet().size() == 0)
        .map(e -> e.getMessage())
        .collect(Collectors.toList());
  }

  public String isValid(String itemName) {
    return (getErrorMessageList(itemName).size() > 0) ? "is-invalid" : "";
  }

  /**
   * エラーメッセージとそのメッセージが指す項目をペアで持つ。 
   * bean validationのような単純にメッセージと項目が1:1となる場合ばかりではなく、
   * 相関チェックだと一つのエラーで複数の項目が対象となったり、対象項目が存在しないエラーなどもある。
   * それらを網羅して保持できるため、一つのメッセージと、0以上の項目をセットで保持できるbeanとする。
   */
  class ErrorMessageBean {
    private String message;

    private Set<String> itemNameSet = new HashSet<>();

    public ErrorMessageBean(String message) {
      this.message = message;
    }

    public ErrorMessageBean(String message, String... itemName) {
      this.message = message;
      this.itemNameSet =
          new HashSet<String>(Arrays.asList(itemName == null ? new String[] {} : itemName));
    }

    public String getMessage() {
      return message;
    }

    public Set<String> getItemNameSet() {
      return itemNameSet;
    }
  }
  
  public static class WarnMessageBean {
    private String messageId;
    private String message;

    public WarnMessageBean(String messageId, String message) {
      this.messageId = messageId;
      this.message = message;
    }

    public String getMessageId() {
      return messageId;
    }

    public void setMessageId(String messageId) {
      this.messageId = messageId;
    }

    public String getMessage() {
      return message;
    }
    public void setMessage(String message) {
      this.message = message;
    }
  }
}

==> ecuacion-splib-web-1.67.0-sources.jar: jp/ecuacion/splib/web/tool/bean/RequestResultBean.java <==
package jp.ecuacion.splib.web.tool.bean;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.HashSet;
import java.util.List;
import java.util.Set;
import java.util.stream.Collectors;

public class RequestResultBean {
  public static final String key = "result";

  private WarnMessageBean warnMessage;

  /**
   * spring mvc標準のbean validationのエラー処理を使用しない場合に使用する。 並び順を保持するためにListを使用。
   */
  private List<ErrorMessageBean> errorMessageList = new ArrayList<>();

  private List<String> getErrorMessageList(String itemName) {
    List<String> returnList = new ArrayList<>();

    for (ErrorMessageBean bean : errorMessageList) {
      if (bean.getItemNameSet().contains(itemName)) {
        returnList.add(bean.message);
      }
    }

    return returnList;
  }

  public WarnMessageBean getWarnMessage() {
    return warnMessage;
  }

  public void setWarnMessage(WarnMessageBean warnMessage) {
    this.warnMessage = warnMessage;
  }

  public void setWarnMessage(String messageId, String message) {
    this.warnMessage = new WarnMessageBean(messageId, message);
  }

  public void setErrorMessage(String message) {
    errorMessageList.add(new ErrorMessageBean(message));
  }

  public void setErrorMessage(String message, String... itemName) {
    errorMessageList.add(new ErrorMessageBean(message, itemName));
  }

  /**
   * 全てのエラーを取得。
   */
  public List<String> getErrorMessages() {
    List<String> rtnList = new ArrayList<>();

    for (ErrorMessageBean bean : errorMessageList) {
      rtnList.add(bean.getMessage());
    }

    return rtnList;
  }

  /**
   * 指定されたitemに対する全てのエラーを取得。
   */
  public List<String> getErrorMessages(String itemName) {
    return getErrorMessageList(itemName);
  }

  /**
   * item指定のある全てのエラーを取得。
   */
  public List<String> getErrorMessagesLinkedToItems() {
    return errorMessageList.stream().filter(e -> e.getItemNameSet().size() > 0)
        .map(e -> e.getMessage()).collect(Collectors.toList());
  }

  /**
   * item指定のない全てのエラーを取得。
   */
  public List<String> getErrorMessagesNotLinkedToItems() {
    return errorMessageList.stream().filter(e -> e.getItemNameSet().size() == 0)
        .map(e -> e.getMessage()).collect(Collectors.toList());
  }

  public String isValid(String itemName) {
    return (getErrorMessageList(itemName).size() > 0) ? "is-invalid" : "";
  }

  /**
   * エラーメッセージとそのメッセージが指す項目をペアで持つ。 bean validationのような単純にメッセージと項目が1:1となる場合ばかりではなく、
   * 相関チェックだと一つのエラーで複数の項目が対象となったり、対象項目が存在しないエラーなどもある。
   * それらを網羅して保持できるため、一つのメッセージと、0以上の項目をセットで保持できるbeanとする。
   */
  class ErrorMessageBean {
    private String message;

    private Set<String> itemNameSet = new HashSet<>();

    public ErrorMessageBean(String message) {
      this.message = message;
    }

    public ErrorMessageBean(String message, String... itemName) {
      this.message = message;
      this.itemNameSet =
          new HashSet<String>(Arrays.asList(itemName == null ? new String[] {} : itemName));
    }

    public String getMessage() {
      return message;
    }

    public Set<String> getItemNameSet() {
      return itemNameSet;
    }
  }

  public static class WarnMessageBean {
    private String messageId;
    private String message;

    public WarnMessageBean(String messageId, String message) {
      this.messageId = messageId;
      this.message = message;
    }

    public String getMessageId() {
      return messageId;
    }

    public void setMessageId(String messageId) {
      this.messageId = messageId;
    }

    public String getMessage() {
      return message;
    }

    public void setMessage(String message) {
      this.message = message;
    }
  }
}
